@@ -1,18 +1,20 @@
 #' Make a tree of an ontology
 #'
-#' @param onto [`tibble(1)`][tibble]\cr the concepts table of an ontology.
+#' @param input [`tibble(1)`][tibble]\cr the concepts table of an ontology.
 #' @param top [`character(1)`][character]\cr the ID from which to derive the
 #'   tree.
-#' @importFrom dplyr filter pull
+#' @importFrom dplyr filter pull arrange
 
-make_tree <- function(onto, top){
+make_tree <- function(input, top){
 
   fin <- NULL
   outIDs <- top
+  input <- input %>%
+    arrange(id)
   while(is.null(fin)){
-    childID <- onto %>%
-      filter(broader %in% top) %>%
-      pull(code)
+    childID <- input %>%
+      filter(has_broader %in% top) %>%
+      pull(id)
     if(length(childID) != 0){
       top <- childID
       outIDs <- c(outIDs, childID)
@@ -21,8 +23,8 @@ make_tree <- function(onto, top){
     }
   }
 
-  temp <- onto %>%
-    filter(code %in% outIDs)
+  temp <- input %>%
+    filter(id %in% outIDs)
 
   return(temp)
 }
